==> modified-shop_1.06-r4642_install.zip: modified-shop_1.06-r4642_install/shoproot/lang/english/admin/campaigns.php <==
<?php
/* --------------------------------------------------------------
   $Id: campaigns.php 1059 2005-07-20 18:26:11Z gwinger $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(manufacturers.php,v 1.14 2003/02/16); www.oscommerce.com 
   (c) 2003	 nextcommerce (manufacturers.php,v 1.4 2003/08/14); www.nextcommerce.org

   Released under the GNU General Public License 
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Campaign Tracking');

define('TABLE_HEADING_CAMPAIGNS', 'Campaigns');
define('TABLE_HEADING_ACTION', 'Aktion');

define('TEXT_HEADING_NEW_CAMPAIGN', 'New campaign');
define('TEXT_HEADING_EDIT_CAMPAIGN', 'Edit campaign');
define('TEXT_HEADING_DELETE_CAMPAIGN', 'delete campaign');

define('TEXT_CAMPAIGNS', 'Campaigns:');
define('TEXT_DATE_ADDED', 'Date added:');
define('TEXT_LAST_MODIFIED', 'Last changes:');
define('TEXT_LEADS', 'Leads:');
define('TEXT_SALES', 'Sales:');
define('TEXT_LATE_CONVERSIONS', 'Late Conversions:');
define('TEXT_NEW_INTRO', 'Please setup a new campaign.');
define('TEXT_EDIT_INTRO', 'Please make all neccessary changes.');

define('TEXT_CAMPAIGNS_NAME', 'Campaignname:');
define('TEXT_CAMPAIGNS_REFID', 'Campaigns refID:');
define('TEXT_DISPLAY_NUMBER_OF_CAMPAIGNS', 'Tracked campaigns:');

define('TEXT_DELETE_INTRO', 'Are you sure you want to delete the campaign?');
?>

==> modified-shop_2.0.7.2-r14622_install.zip: modified-shop_2.0.7.2-r14622_install/shoproot/lang/english/admin/campaigns.php <==
<?php
/* --------------------------------------------------------------
   $Id: campaigns.php 13533 2021-04-19 07:24:24Z GTB $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(manufacturers.php,v 1.14 2003/02/16); www.oscommerce.com 
   (c) 2003	 nextcommerce (manufacturers.php,v 1.4 2003/08/14); www.nextcommerce.org

   Released under the GNU General Public License 
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Campaign Tracking');

define('TABLE_HEADING_CAMPAIGNS', 'Campaigns');
define('TABLE_HEADING_ACTION', 'Aktion');

define('TEXT_HEADING_NEW_CAMPAIGN', 'New campaign');
define('TEXT_HEADING_EDIT_CAMPAIGN', 'Edit campaign');
define('TEXT_HEADING_DELETE_CAMPAIGN', 'delete campaign');

define('TEXT_CAMPAIGNS', 'Campaigns:');
define('TEXT_DATE_ADDED', 'Date added:');
define('TEXT_LAST_MODIFIED', 'Last changes:');
define('TEXT_LEADS', 'Leads:');
define('TEXT_SALES', 'Sales:');
define('TEXT_LATE_CONVERSIONS', 'Late Conversions:');
define('TEXT_NEW_INTRO', 'Please setup a new campaign.');
define('TEXT_EDIT_INTRO', 'Please make all neccessary changes.');
define('TEXT_REFERER','Referer: ');

define('TEXT_CAMPAIGNS_NAME', 'Campaignname:');
define('TEXT_CAMPAIGNS_REFID', 'Campaigns refID:');
define('TEXT_DISPLAY_NUMBER_OF_CAMPAIGNS', 'Tracked campaigns:');

define('TEXT_DELETE_INTRO', 'Are you sure you want to delete the campaign?');
define('TEXT_DELETE_REFFERERS', 'Delete Conversions');
define('TEXT_DELETE_WARNING_REFFERERS', 'Delete all conversions for this campaign?');

define('TEXT_CAMPAIGNS_ERROR_REFID', 'refID is invalid');
define('TEXT_CAMPAIGNS_ERROR_REFID_EXISTS', 'refID is already in use');
?>
